@@ -26,28 +26,29 @@ expect_that <- function(object, condition, info = NULL, label = NULL) {
   condition(object)
 }
 
-#' Default expectations that alway succeed or fail.
+#' Default expectations that always succeed or fail.
 #'
 #' These allow you to manually trigger success or failure. Failure is
 #' particularly useful to a pre-condition or mark a test as not yet
 #' implemented.
 #'
 #' @param message a string to display.
+#' @inheritParams expect
 #' @export
 #' @examples
 #' \dontrun{
 #' test_that("this test fails", fail())
 #' test_that("this test succeeds", succeed())
 #' }
-fail <- function(message = "Failure has been forced") {
-  expect(FALSE, message)
+fail <- function(message = "Failure has been forced", info = NULL) {
+  expect(FALSE, message, info = info)
 }
 
 
 #' @rdname fail
 #' @export
-succeed <- function(message = "Success has been forced") {
-  expect(TRUE, message)
+succeed <- function(message = "Success has been forced", info = NULL) {
+  expect(TRUE, message, info = info)
 }
 
 #' Negate an expectation
